unit LaunchReportWizardInCode;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Db, DBTables, ppComm, ppRelatv, ppCache, ppDB, ppDBPipe, ppReport,
  ppRptWiz, ppFormWrapper;

type

  TForm1 = class(TForm)
    btnLaunchWizard: TButton;
    plCustomer: TppDBPipeline;
    plOrder: TppDBPipeline;
    plSeaFish: TppDBPipeline;
    Table1: TTable;
    DataSource1: TDataSource;
    Table2: TTable;
    DataSource2: TDataSource;
    Table3: TTable;
    DataSource3: TDataSource;
    procedure btnLaunchWizardClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
  private
    FDataPipelines: TStrings;
    FReport: TppReport;

    procedure CreateReportEvent(Sender: TObject; const aDataName: String; var aReport: TObject);
    function  DataPipelineForName(const aDataName: String): TppDataPipeline;
    procedure GetDataNamesEvent(Sender: TObject; aDataNameList: TStrings);
    procedure GetFieldsEvent(Sender: TObject; const aDataName: String; aFieldList: TStrings);
    procedure ValidateNameEvent(Sender: TObject; const aName: String; var aNameValid: Boolean);
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}


procedure TForm1.FormCreate(Sender: TObject);
begin
  FDataPipelines := TStringList.Create;

  FDataPipelines.AddObject('Customers', plCustomer);
  FDataPipelines.AddObject('Orders', plOrder);
  FDataPipelines.AddObject('Sea Fish', plSeaFish);

end;

procedure TForm1.FormDestroy(Sender: TObject);
begin
  FDataPipelines.Free;
end;

procedure TForm1.btnLaunchWizardClick(Sender: TObject);
var
  lWizard: TppReportWizard;
begin

  lWizard := TppReportWizard.Create(Self);
  lWizard.OnCreateReport := CreateReportEvent;
  lWizard.OnGetDataNames := GetDataNamesEvent;
  lWizard.OnGetFields := GetFieldsEvent;
  lWizard.OnValidateName := ValidateNameEvent;

  FReport := nil;

  if (lWizard.Execute) then
    FReport.Print;

  lWizard.Free;

  FReport.Free;
end;

procedure TForm1.CreateReportEvent(Sender: TObject; const aDataName: String; var aReport: TObject);
begin
  FReport := TppReport.Create(Self);

  FReport.DataPipeline := DataPipelineForName(aDataName);

  aReport := FReport;
end;

procedure TForm1.GetDataNamesEvent(Sender: TObject; aDataNameList: TStrings);
begin
  aDataNameList.Assign(FDataPipelines);
end;

procedure TForm1.GetFieldsEvent(Sender: TObject; const aDataName: String; aFieldList: TStrings);
var
  lDataPipeline: TppDataPipeline;
  liIndex: Integer;
begin

  lDataPipeline := DataPipelineForName(aDataName);

  if (lDataPipeline <> nil) then
    for liIndex := 0 to lDataPipeline.FieldCount - 1 do
      aFieldList.AddObject(lDataPipeline.Fields[liIndex].FieldAlias, lDataPipeline.Fields[liIndex]);
end;

procedure TForm1.ValidateNameEvent(Sender: TObject; const aName: String; var aNameValid: Boolean);
begin
  aNameValid := True;
end;

function TForm1.DataPipelineForName(const aDataName: String): TppDataPipeline;
var
  liIndex: Integer;
begin
  liIndex := FDataPipelines.IndexOf(aDataName);

  if (liIndex <> -1) then
    Result := TppDataPipeline(FDataPipelines.Objects[liIndex])
  else
    Result := nil;
end;



end.
